@@ -1,4 +1,7 @@
-import simplejson as json
+try:
+    import json
+except ImportError:
+    import simplejson as json
 
 class ResponseParser(object):
     """
